@@ -61,6 +61,8 @@ class Base(object):
     def load_an_table(self, table):
         sql = 'show fields from ' + table
         res = self.query(sql, show_sql=False)
+        if res is None:
+            return
         column_list = list(map(lambda x: x[0], res))
         if 'signal' in column_list:
             column_list.remove('signal')
@@ -103,6 +105,8 @@ class Base(object):
                 fields = self._tables[table]
             else:
                 fields = self.load_an_table(table)
+        if fields is None:
+            return
         sql = 'select %s from %s where  ' % (','.join(fields), table)
         # if conditions == []:
         sql = Base.bind_conditions(sql, conditions, or_cond)
@@ -156,6 +160,8 @@ class Base(object):
     # 查找数据（单条）
     def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False):
         sql = self.find_info(table, conditions, or_cond, fields, None, order)
+        if sql is None:
+            return
 
         sql += " limit 1"
         # 
@@ -181,7 +187,8 @@ class Base(object):
     # 查找数据
     def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False):
         sql = self.find_info(table, conditions, or_cond, fields, group, order, limit)
-
+        if sql is None:
+            return
         # 
         res = self.query(sql, show_sql)
         if res is None:
